package beilv.site.service.impl;

import java.util.List;
import java.util.Map;

import beilv.shopping.domain.QmjsShoppingMall;
import beilv.system.domain.SysPost;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import beilv.site.mapper.BeilvSiteMapper;
import beilv.site.domain.BeilvSite;
import beilv.site.service.IBeilvSiteService;
import beilv.common.core.text.Convert;

/**
 * 球场管理Service业务层处理
 *
 * @author lc
 * @date 2025-01-06
 */
@Service
public class BeilvSiteServiceImpl implements IBeilvSiteService {
    @Autowired
    private BeilvSiteMapper beilvSiteMapper;

    /**
     * 查询球场管理
     *
     * @param id 球场管理主键
     * @return 球场管理
     */
    @Override
    public BeilvSite selectBeilvSiteById(Long id) {
        return beilvSiteMapper.selectBeilvSiteById(id);
    }


    /**
     * 查询球场管理列表
     *
     * @param beilvSite 球场管理
     * @return 球场管理
     */
    @Override
    public List<BeilvSite> selectBeilvSiteList(BeilvSite beilvSite) {
        return beilvSiteMapper.selectBeilvSiteList(beilvSite);
    }

    /**
     * 新增球场管理
     *
     * @param beilvSite 球场管理
     * @return 结果
     */
    @Override
    public int insertBeilvSite(BeilvSite beilvSite) {
        if (beilvSiteMapper.selectOne(beilvSite)) {
            return -1;
        } else {
            return beilvSiteMapper.insertBeilvSite(beilvSite);
        }
    }

    /**
     * 修改球场管理
     *
     * @param beilvSite 球场管理
     * @return 结果
     */
    @Override
    public int updateBeilvSite(BeilvSite beilvSite) {
        if (beilvSiteMapper.selectOne(beilvSite)) {
            return -1;
        } else {
            return beilvSiteMapper.updateBeilvSite(beilvSite);
        }

    }

    /**
     * 批量删除球场管理
     *
     * @param ids 需要删除的球场管理主键
     * @return 结果
     */
    @Override
    public int deleteBeilvSiteByIds(String ids) {
        return beilvSiteMapper.deleteBeilvSiteByIds(Convert.toStrArray(ids));
    }

    /**
     * 删除球场管理信息
     *
     * @param id 球场管理主键
     * @return 结果
     */
    @Override
    public int deleteBeilvSiteById(Long id) {
        return beilvSiteMapper.deleteBeilvSiteById(id);
    }

    @Override
    public List<BeilvSite> getAllToList() {
        return beilvSiteMapper.getAllToList();
    }

    /**
     * 球场状态修改
     */
    @Override
    public int siteStatus(BeilvSite beilvSite) {
        return beilvSiteMapper.updateBeilvSite(beilvSite);
    }

    @Override
    public List<Map<String, String>> selectSiteTypeByVenueId(BeilvSite beilvSite) {
        return beilvSiteMapper.selectSiteTypeByVenueId(beilvSite);
    }
}
